% est_abf_X_Y.m estimates the strategies using SFEM for treament X and
% matches Y

warning off all

% sets the path to facilitate calls loading and saving data
if ismac == 1
    cd ../../Dropbox/abf    % that's the path for the iMac in the country
elseif ismac == 0
    if isunix == 1
        cd /home/guillaume/Desktop/Shared/gfrechette/Dropbox/abf
    elseif isunix == 0
        cd c:/gfrechette/Dropbox/abf
    else
        disp('Error: OS not recognised');
    end
else
    disp('Error: OS not recognised');
end

% creating a diary
delete('./log/est_abf_3_l4_frd_p.txt');
diary('./log/est_abf_3_l4_frd_p.txt');
format long;

% input data
clear
All = load( './data/raw/dat_for_matlab_3_l4.txt' ); match = All(:, 1);
match = All(:, 1);
round = All(:, 2);
session = All(:, 3);
treatment = All(:, 4);
id_all = All(:, 5);
strg = All(:,[6:end]); include = [1:3,6,7,9,11,12,13,14,15,20,21,27,28]; strg = strg(:, include);

% generate new vars
max_id = max(id_all);
min_id = min(id_all);
for i = min_id:max_id
    max_match(i) = max(match(find(id_all==i)));
    min_match(i) = min(match(find(id_all==i)));
end
K = size(strg,2);
% what follows defines a subset of two strategies (should be always
% cooperate and always defect) to start the optimization
include_1 = [1:2];
strg_1 = strg(:, include_1);
K_1 = size(strg_1,2);

% optimization (2 strategies)
disp('strategies 1-2');
[x, ll, hess, exitflag] = opt_abf(match, min_match, max_match, id_all, min_id, max_id, strg_1, K_1, 0);
for m = 1:50
    m
    start_foo = [(m/50)*3; mean(strg(:,1))];
    [x_foo, ll_foo, hess_foo, exitflag_foo] = opt_abf(match, min_match, max_match, id_all, min_id, max_id, strg_1, K_1, start_foo);
    if ll_foo <= ll & exitflag_foo ~= 0
        x = x_foo; ll = ll_foo; hess = hess_foo; exitflag = exitflag_foo;
    end
end
if min(x) < 0, foo = x; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x=foo; end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% this parts always estimates 3 strategies, AC, AD, and one more at a time.
% It takes all the results and averages them to obtain the starting value
% for the estimation with all teh strategies
% This means that the starting value will put lots of weight on AC and AD.

start = [ 0.9*x ; 0.9*(1-x(2,1)) ];   % this puts 10% on a new strategy and 90% on AC and AD
superstart = zeros(K,1);

disp('strategies 1-2 and...');
for j = 3:K
    j
    include_j = [1:2,j]; strg_j = strg(:, include_j);
    K_2 = size(strg_j,2);
    
    % optimization (3 strategies)
    [x_j, ll_j, hess_j, exitflag_j] = opt_abf(match, min_match, max_match, id_all, min_id, max_id, strg_j, K_2, start);
    if min(x_j) < 0, foo = x_j; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x_j=foo; end
    superstart(1:3,1) = x_j(1:3,1) + superstart(1:3,1);
    superstart(j,1) = 1-sum(x_j(2:end));
end
superstart = superstart/(K-2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% optimization (All strategies)
disp('all strategies');
%increase = K-size(x,1);
[x, ll, hess, exitflag] = opt_abf(match, min_match, max_match, id_all, min_id, max_id, strg, K, superstart);
if min(x) < 0, foo = x; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x=foo; end

% play with results
gamma = x(1,1);
% negative values should be interpreted as near zero (see ll_part1_b)
p = x([2:end],1);
p(K,1) = 1 - sum(x([2:end],1));

% Bootsrapping the variance-covariance matrix
start_bs = x;  
[x_M, vc_bs] = bs_abf(match, id_all, strg, K, start_bs, session, 1000);

% spiting out some data
output(1,:) = [ll gamma p'];
output;
ll
disp('p')
[include', p]
gamma
[0, sqrt(diag(vc_bs(1,1))); include(1:end-1)', sqrt(diag(vc_bs(2:end,2:end)))]



save('./data/raw/est_abf_3_l4_frd_p', 'x', 'gamma', 'include', 'p', 'll', 'vc_bs', 'x_M', '-double', '-tabs')

diary off
