/******************************************************
      ../abd/do/tes_benchmark.do
	game: Randomly terminated PD with variation in monitoring
	first created: 06/22/17

  Compares the data to predictions from the JEL

******************************************************/

* setting up stuff
clear
clear matrix
capture log close
set more 1
set mem 100m

* Set path directory
if c(os) == "MacOSX" {
   cd "/Users/gfrechette/Dropbox (CfESS)/abf/"
}
else {
   cd "c:/gfrechette/Dropbox (CfESS)/abf/"
}

///////// Predictions for original and additional experiments in terms of cooperation
* For the original set of experiments, the parameters are:
* g= 0.3571, l= 0.3571, delta=0.9
* For the additional set of experiments, the parameters are:
* g= 0.5405405405, l= 0.540540540, delta=0.9

* coop is spe id delta > g/(1+g)
display 0.3571 / ( 1 + 0.3571 )
display 0.5405405405 / ( 1 + 0.5405405405 )

* coop is rd if delta > ( g + l ) / ( 1 + g + l )
display ( 0.3571 + 0.3571 ) / ( 1 + 0.3571 + 0.3571 )
display ( 0.5405405405 + 0.540540540 ) / ( 1 + 0.5405405405 + 0.540540540 )


*use "../published/df_jel/data/stata/dat_pres.dta",replace
use "../df_jel/data/stata/dat_pres.dta",replace
drop if round > 1
drop if order > 1

keep if supergame >= 8 & supergame <= 11

mat pred_mat = J(8,2,0) /* matrix to store the estimation results */

********************************
* Use all treatments from meta *
********************************
probit coop g l delta sgpe rd, cluster(paper)
* Original set of experiments
mfx, predict(p) at(g= 0.3571, l= 0.3571, delta=0.9, sgpe=1, rd=1) nose
mat pred_mat[1,1] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.3571, l= 0.3571, delta=0.9, sgpe=1, rd=1) nose
mat pred_mat[2,1] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */
mfx, predict(p) at(g= 0.3571, l= 0.3571, delta=0, sgpe=0, rd=0) nose
mat pred_mat[3,1] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.3571, l= 0.3571, delta=0, sgpe=0, rd=0) nose
mat pred_mat[4,1] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */
* Additional experiments
mfx, predict(p) at(g= 0.540540540, l= 0.540540540, delta=0.9, sgpe=1, rd=1) nose
mat pred_mat[5,1] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.540540540, l= 0.540540540, delta=0.9, sgpe=1, rd=1) nose
mat pred_mat[6,1] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */
mfx, predict(p) at(g= 0.540540540, l= 0.540540540, delta=0, sgpe=0, rd=0) nose
mat pred_mat[7,1] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.540540540, l= 0.540540540, delta=0, sgpe=0, rd=0) nose
mat pred_mat[8,1] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */

matlist pred_mat

************************************
* Use only sessions with delta = 0 *
************************************

/// Predicted round 1 cooperation level for Aoyagi et al. values for delta=0 and delta=.9 ///
use "../df_jel/data/stata/dat_pres.dta",replace
drop if round > 1
drop if order > 1
drop if delta > 0
tab paper

keep if ( supergame >= 8 & supergame <= 11 )

probit coop g l, cluster(paper)
mfx, predict(p) at(g= 0.3571, l= 0.3571) nose
mat pred_mat[3,2] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.3571, l= 0.3571) nose
mat pred_mat[4,2] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */
mfx, predict(p) at(g= 0.540540540, l= 0.540540540) nose
mat pred_mat[7,2] = e(Xmfx_y)  /* predicted value saved as first entry of the matrix */
mfx, predict(stdp) at(g= 0.540540540, l= 0.540540540) nose
mat pred_mat[8,2] = e(Xmfx_y)  /* standard error of the prediction saved as entry entry of the matrix */

matlist pred_mat



///////////////////// FOR ORIGINAL SET OF SESSIONS: Beta = 10 ////////////////////////

********************************
* Use all treatments from meta *
********************************


* Standard deviation for t-test below
* Computed from standard error of the prediction above
* when delta = 0.9
* disp display .0948618*sqrt(5)
* .21211743

* Standard deviation for t-test below
* Computed from standard error of the prediction above
* for one-shot game
* disp .17342486*sqrt(5)
* .38778978


use "data/stata/dat_same_01.dta", clear
* only keep last 4 matches
keep if exp_2 == 1
keep if round == 1

* Treatment 1: Perfect
reg coop if treatment == 1, cluster(session)

* Standard deviation for t-test below
* disp .0620795*sqrt(3)
* .10752485

* 15 is the number of clusters in the meta
* 4 is the number of clusters in the experiment
* delta = 0.9 prediction
ttesti 15 .760716 .21211743 4 .6439394 .10752485, unequal
* delta = 0 prediction
ttesti 15 .29692271 .38778978 4 .6439394 .10752485, unequal

* Treatment 2: Public
reg coop if treatment == 2, cluster(session)

* Standard deviation for t-test below
* disp .0674824*sqrt(3)
* .11688295

* delta = 0.9 prediction
ttesti 15 .760716 .21211743 4 .7279412 .11688295, unequal
* delta = 0 prediction
ttesti 15 .29692271 .38778978 4 .7279412 .11688295, unequal

* Treatment 3: Private
reg coop if treatment == 3, cluster(session)

* Standard deviation for t-test below
* 3 are the degrees of freedom (see F test in reg output)
* disp .0445188*sqrt(3)
* .07710882

* delta = 0.9 prediction
ttesti 15 .760716 .21211743 4 .6145833 .07710882, unequal
* delta = 0 prediction
ttesti 15 .29692271 .38778978 4 .6145833 .07710882, unequal


************************************
* Use only sessions with delta = 0 *
************************************

* Standard deviation for t-test below
* Computed from standard error of the prediction above
* for one-shot game
* disp .19344455*sqrt(2)
* .27357191


use "data/stata/dat_same_01.dta", clear
* only keep last 4 matches
keep if exp_2 == 1
keep if round == 1

* Treatment 1: Perfect
reg coop if treatment == 1, cluster(session)

* Standard deviation for t-test below
* disp .0620795*sqrt(3)
* .10752485

* delta = 0 prediction
ttesti 5 .33907126 .27357191 4 .6439394 .10752485, unequal

* Treatment 2: Public
reg coop if treatment == 2, cluster(session)

* Standard deviation for t-test below
* disp .0674824*sqrt(3)
* .11688295

* delta = 0 prediction
ttesti 5 .33907126 .27357191 4 .7279412 .11688295, unequal

* Treatment 3: Private
reg coop if treatment == 3, cluster(session)

* Standard deviation for t-test below
* disp .0445188*sqrt(3)
* .07710882

* delta = 0 prediction
ttesti 5 .33907126 .27357191 4 .6145833 .07710882, unequal



///////////////////// FOR ADDITIONAL SESSIONS: Beta = 20 ////////////////////////

********************************
* Use all treatments from meta *
********************************

* Standard deviation for t-test below
* Computed from standard error of the prediction above
* when delta = 0.9
* display .0880662*sqrt(5)
* .19498267

* Standard deviation for t-test below
* Computed from standard error of the prediction above
* for one-shot game
* disp .16757183*sqrt(5)
* .37549395


use "data/stata/dat_same_2.dta", clear
* only keep last 4 matches
keep if exp_2 == 1
keep if round == 1

* Treatment 1: Perfect
reg coop if treatment == 1, cluster(session)

* Standard deviation for t-test below
* disp .0136719*sqrt(1)
* .0136719

* 15 is the number of clusters in the meta
* 2 is the number of clusters in the experiment
* delta = 0.9 prediction
ttesti 15 .7274232 .19498267 2 .3515625 .0136719, unequal
* delta = 0 prediction
ttesti 15 .2621142 .37549395 2 .3515625 .0136719, unequal

* Treatment 2: Public
reg coop if treatment == 2, cluster(session)

* Standard deviation for t-test below
* disp .005*sqrt(1)
* .005

* delta = 0.9 prediction
ttesti 15 .7274232 .19498267 2 .35 .005, unequal
* delta = 0 prediction
ttesti 15 .2621142 .37549395 2 .35 .005, unequal

* Treatment 3: Private
reg coop if treatment == 3, cluster(session)

* Standard deviation for t-test below
* disp .0520833*sqrt(1)
* .0520833

* delta = 0.9 prediction
ttesti 15 .7274232 .19498267 2 .40625 .0520833, unequal
* delta = 0 prediction
ttesti 15 .2621142 .37549395 2 .40625 .0520833, unequal


************************************
* Use only sessions with delta = 0 *
************************************

* Standard deviation for t-test below
* Computed from standard error of the prediction above
* for one-shot game
* disp .16953514*sqrt(2)
* .23882192

use "data/stata/dat_same_2.dta", clear
* only keep last 4 matches
keep if exp_2 == 1
keep if round == 1

* Treatment 1: Perfect
reg coop if treatment == 1, cluster(session)

* Standard deviation for t-test below
* disp .0136719*sqrt(1)
* .0136719

* delta = 0 prediction
ttesti 5 .2990871 .23882192 2 .3515625 .0136719, unequal

* Treatment 2: Public
reg coop if treatment == 2, cluster(session)

* Standard deviation for t-test below
* disp .005*sqrt(1)
* .005

* delta = 0 prediction
ttesti 5 .2990871 .23882192 2 .35 .005, unequal

* Treatment 3: Private
reg coop if treatment == 3, cluster(session)

* Standard deviation for t-test below
* disp .0520833*sqrt(1)
* .0520833

* delta = 0 prediction
ttesti 5 .2990871 .23882192 2 .40625 .0520833, unequal
