/******************************************************
      ../abd/do/tes_text_Z.do
	game: Randomly terminated PD with variation in monitoring
	first created: 09/24/12
	modified for version gf9

	the last characters idefentifies the version

******************************************************/

* setting up stuff
clear
clear matrix
capture log close
set more 1
set mem 100m

* Set path directory
if c(os) == "MacOSX" {
   cd "/Users/gfrechette/Dropbox (CfESS)/abf/"
}
else {
   cd "c:/gfrechette/Dropbox (CfESS)/abf/"
}




//Table 1: Summary Information
use "data/stata/dat_2.dta", clear				/* uses all data, not just same == 1 */
table random treatment, c(max subject)	/* no of subjects per session */
table random treatment, c(max match)	/* no of matches per session */
collapse length, by(treatment date match)
table treatment, c(mean length min length max length)
sum length
use "data/stata/dat_2.dta", clear				/* uses all data, not just same == 1 */
collapse (max) cum_payoff, by(treatment random date id)
gen pay = 0.0075*cum_payoff
table treatment, c(mean pay min pay max pay)
sum pay


/*  Figure that compares cooperation rates by treatment with epsilon = 0.1 to epsilon = 0.2
    vs what the predicted values are.
*/
use "data/stata/dat_same_01.dta", clear
keep if exp_2 == 1
keep if round == 1

reg coop if treatment == 1, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) replace
reg coop if treatment == 2, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) append
reg coop if treatment == 3, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) append


use "data/stata/dat_same_2.dta", clear
keep if exp_2 == 1
keep if round == 1

reg coop if treatment == 1, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) append
reg coop if treatment == 2, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) append
reg coop if treatment == 3, cluster(session) level(90)
regsave using "data/stata/fig_robust.dta", ci level(90) append

use "data/stata/fig_robust.dta", replace

gen epsilon = 20 if _n <= 3
replace epsilon = 10 if _n > 3
gen treatment = 1 if _n == 3 | _n == 6
replace treatment = 2 if _n == 2 | _n == 5
replace treatment = 3 if _n == 1 | _n == 4
* make 95% interval fall between 0 and 1
replace ci_upper = 1 if ci_upper > 1
replace ci_lower = 0 if ci_lower < 0

* Predicted values obtained from est_becnhmark.do
* Specifically only including one-shot games.
* epsilon = 0.1
graph tw bar coef treatment if epsilon == 10, barwidth(0.8) || ///
   rcap ci_upper ci_lower treatment if epsilon == 10 || ///
   scatteri 0.760716 0.5 0.760716 3.5, c(l) m(i) lcolor(gs5) || ///
   scatteri 0.33907126 0.5 0.33907126 3.5, c(l) m(i) lcolor(gs5) lpattern(dash) ///
 title("{&epsilon} = 0.1") ///
   ylabel(0(0.2)1) ///
   ytitle("Frequency of Cooperation") ///
   xlabel(1 "Perfect" 2 "Public" 3 "Private") ///
   xtitle("Treatment") ///
   legend(off) ///
   graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
   saving("graph/foo", replace)

* Epsilon = 0.2
graph tw bar coef treatment if epsilon == 20, barwidth(0.8) || ///
   rcap ci_upper ci_lower treatment if epsilon == 20 || ///
   scatteri 0.7274232 0.5 0.7274232 3.5, c(l) m(i) lcolor(gs5) || ///
   scatteri 0.2990871 0.5 0.2990871 3.5, c(l) m(i) lcolor(gs5) lpattern(dash) ///
   title("{&epsilon} = 0.2") ///
   ylabel(0(0.2)1) ///
   ytitle("Frequency of Cooperation") ///
   xlabel(1 "Perfect" 2 "Public" 3 "Private") ///
   xtitle("Treatment") ///
 legend(label(1 "Data From" "Experiment") label(2 "90% CI") label(3 "Prediction" "For {&delta} = 0.9") label(4 "Prediction" "For {&delta} = 0") ring(0) pos(2) bmargin(large) size(vsmall) rows(2)) ///
   graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
   saving("graph/bar", replace)

graph combine "graph/foo.gph" "graph/bar.gph", ///
  ycommon xcommon row(1) graphregion(color(white)) ///
  note("Predictions generated using the meta-data from Dal Bo and Frechette (2016).", size(small)) ///
  saving("graph/baz", replace)

graph export "text/files/coop_round_1_epsilon.eps", replace


// Is there a decrease in coop as epsilon increases?
use "data/stata/dat_same_01.dta", clear
gen epsilon = 10
append using "data/stata/dat_same_2.dta"
replace epsilon = 20 if epsilon == .

gen epsilon_20 = ( epsilon == 20 )

reg coop epsilon_20 if treatment == 1 & round == 1 & exp_2 == 1, cluster(session)
reg coop epsilon_20 if treatment == 2 & round == 1 & exp_2 == 1, cluster(session)
reg coop epsilon_20 if treatment == 3 & round == 1 & exp_2 == 1, cluster(session)

// Are the round 1 coop rate distinguishable?
gen rand_2 = ( random == 2 & epsilon == 20 )
reg coop public private rand_2 if epsilon == 20 & round == 1 & exp_2 == 1, cluster(session)
test public
test private, accum



// Are the cooperation rates different from what they are predicted to be in a one-shot game

*do est_becnhmark.do



// EQUIVALENT OF SECTION 7.3

//  EQUIVALENT OF Figure 4: Conditional Cooperation Rates

* do they react to the signals
use "data/stata/dat_same_2.dta", clear

egen foo = max(match), by(treatment random)
gen match_end = match - foo + 19

gen match_combo = match if match <= 4
replace match_combo = match_end - 10 if match_end >= 16
replace match_combo = 5 if match_combo == .

collapse coop, by(treatment match_combo ocsignal_m1)

label var match_combo Match

tw scatter coop match_combo if treatment == 1 & ocsignal_m1 == ., connect(l) msymbol(T) lpattern(dot) || scatter coop match_combo if treatment == 1 & ocsignal_m1 == 1, connect(l) msymbol(o) lpattern(solid) || scatter coop match_combo if treatment == 1 & ocsignal_m1 == 0, connect(l) msymbol(Oh) lpattern(dash) ytitle("Frequency of Cooperation") xtitle("Supergame") t1title("Perfect") yscale(r(1)) ylabel(0(0.2)1) xlabel(1 "1" 2 "2" 3 "3" 4 "4" 9 "Last" 8 "L-1" 7 "L-2" 6 "L-3" 5 "O", alternate) xline(4) xline(6) legend(off) graphregion(color(white)) bgcolor(white) scheme(s2mono) saving("graph/foo", replace)

tw scatter coop match_combo if treatment == 2 & ocsignal_m1 == ., connect(l) msymbol(T) lpattern(dot) || scatter coop match_combo if treatment == 2 & ocsignal_m1 == 1, connect(l) msymbol(o) lpattern(solid) || scatter coop match_combo if treatment == 2 & ocsignal_m1 == 0, connect(l) msymbol(Oh) lpattern(dash) ytitle("") xtitle("Supergame") t1title("Public") yscale(r(1)) ylabel(0(0.2)1) xlabel(1 "1" 2 "2" 3 "3" 4 "4" 9 "Last" 8 "L-1" 7 "L-2" 6 "L-3" 5 "O", alternate) xline(4) xline(6) legend(off) graphregion(color(white)) bgcolor(white) scheme(s2mono) saving("graph/bar", replace)

tw scatter coop match_combo if treatment == 3 & ocsignal_m1 == ., connect(l) msymbol(T) lpattern(dot) || scatter coop match_combo if treatment == 3 & ocsignal_m1 == 1, connect(l) msymbol(o) lpattern(solid) || scatter coop match_combo if treatment == 3 & ocsignal_m1 == 0, connect(l) msymbol(Oh) lpattern(dash) ytitle("") xtitle("Supergame") t1title("Private") yscale(r(1)) ylabel(0(0.2)1) xlabel(1 "1" 2 "2" 3 "3" 4 "4" 9 "Last" 8 "L-1" 7 "L-2" 6 "L-3" 5 "O", alternate) xline(4) xline(6) legend(label(1 "{it:t} = 1") label(2 "{&omega}{sub:i}{sup:t-1}={it:c}") label(3 "{&omega}{sub:i}{sup:t-1}={it:d}") ring(0) pos(1) size(small)) graphregion(color(white)) bgcolor(white) scheme(s2mono) saving("graph/baz", replace)

graph combine "graph/foo.gph" "graph/bar.gph" "graph/baz.gph", ycommon xcommon row(1) graphregion(color(white)) saving("graph/cond_coop_robust", replace)

graph export "text/files/cond_coop_robust.eps", replace



// stat tests and differences in cond coop rates
use "data/stata/dat_same_2.dta", clear
bysort treatment: reg coop ocsignal if round > 1 & exp_2 == 1, cluster(session)

// Corresponding numbers in original experiment
use "data/stata/dat_same_01.dta", clear
bysort treatment: reg coop ocsignal if round > 1 & exp_2 == 1, cluster(session)



// coop rate and stat tests for coop rate considering all rounds
use "data/stata/dat_same_2.dta", clear
table treatment if exp_2 == 1, c(mean coop)
tab random, g(rand_)
reg coop public private rand_2 if exp_2 == 1, cluster(session)
test public
test private, accum
test public = private


// Equivalent to SECTION 7.2 Coordination

// Equivalent to Figure 3: Coordination Rates
use "data/stata/dat_same_2.dta", clear

egen foo = max(match), by(treatment random)
gen match_end = match - foo + 19

gen match_combo = match if match <= 4
replace match_combo = match_end - 10 if match_end >= 16
replace match_combo = 5 if match_combo == .

gen coord_1 = coop*ocoop
gen coord_0 = (1-coop)*(1-ocoop)

collapse coord_0 coord_1 coop if exp_2 == 1 & round <= 5, by(treatment round)

gen exp_0 = (1-coop)^2
gen exp_1 = coop^2

gen coord = coord_0 + coord_1

tw scatter exp_0 round, connect(l) msymbol(T) lpattern(solid) || ///
  scatter exp_1 round, connect(l) msymbol(O) lpattern(dash) || ///
  scatter coord_0 round, connect(l) msymbol(Th) lpattern(solid)  || ///
  scatter coord_1 round, connect(l)  msymbol(Oh) lpattern(dash)  || ///
  scatter coord round, connect(l)  msymbol(d) lpattern(dot) ///
  ytitle("Coordination Rate") xtitle("Round") ylabel(0(0.2)0.8) ///
  legend(label(1 "Pr({it:a}{sub:{it:i}}{sup:{it:t}}={it:D}){sup:2}") label(2 "Pr({it:a}{sub:{it:i}}{sup:{it:t}}={it:C}){sup:2}") label(3 "Pr({it:a}{sup:{it:t}}=({it:D},{it:D}))") label(4 "Pr({it:c}{sup:{it:t}}=({it:C},{it:C}))") label(5 "Total") size(small) rows(1)) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
  by(treatment, row(1) note("* Last 4 Matches") graphregion(color(white)) bgcolor(white)) ///
  saving("graph/coord", replace)

  graph export "text/files/coord_robust.eps", replace



* is the difference between the actual coordination rate and the expected statistically significant?
* test done two ways
use "data/stata/dat_same_2.dta", clear
gen coord_1 = coop*ocoop
gen coord_0 = (1-coop)*(1-ocoop)
gen coord = coord_0 + coord_1
collapse coord_0 coord_1 coord coop, by(treatment date match exp_2)
gen expec_1 = coop^2
gen expec_0 = (1-coop)^2
gen expec = expec_0 + expec_1
* perfect
reg coord expec if treatment==1 & exp_2==1, nocon cluster(date)
test expec = 1
gen diff = coord - expec
reg diff if treatment==1 & exp_2==1, cluster(date)
* public
reg coord expec if treatment==2 & exp_2==1, nocon cluster(date)
test expec = 1
reg diff if treatment==2 & exp_2==1, cluster(date)
* private
reg coord expec if treatment==3 & exp_2==1, nocon cluster(date)
test expec = 1
reg diff if treatment==3 & exp_2==1, cluster(date)
